commands: replace "working copy" with "working directory" in help/messages
authorYuya Nishihara <yuya@tcha.org>
Tue, 17 Mar 2015 22:47:08 +0900
changeset 24364 135b23868f45
parent 24363 852801178a63
child 24365 f1eaf03dd608
commands: replace "working copy" with "working directory" in help/messages "working directory" is the standard term, we should use it consistently. But I didn't touch the hint, "run 'hg update' to get a working copy", because "get a working directory" sounds a bit odd.
hgext/share.py
hgext/strip.py
mercurial/cmdutil.py
mercurial/commands.py
tests/test-copy.t
tests/test-globalopts.t
tests/test-help.t
tests/test-strip.t
--- a/hgext/share.py	Tue Mar 17 22:21:09 2015 -0400
+++ b/hgext/share.py	Tue Mar 17 22:47:08 2015 +0900
@@ -15,7 +15,7 @@
 testedwith = 'internal'
 
 @command('share',
-    [('U', 'noupdate', None, _('do not create a working copy')),
+    [('U', 'noupdate', None, _('do not create a working directory')),
      ('B', 'bookmarks', None, _('also share bookmarks'))],
     _('[-U] [-B] SOURCE [DEST]'),
     norepo=True)
--- a/hgext/strip.py	Tue Mar 17 22:21:09 2015 -0400
+++ b/hgext/strip.py	Tue Mar 17 22:47:08 2015 +0900
@@ -81,7 +81,8 @@
           ('', 'no-backup', None, _('no backups')),
           ('', 'nobackup', None, _('no backups (DEPRECATED)')),
           ('n', '', None, _('ignored  (DEPRECATED)')),
-          ('k', 'keep', None, _("do not modify working copy during strip")),
+          ('k', 'keep', None, _("do not modify working directory during "
+                                "strip")),
           ('B', 'bookmark', '', _("remove revs only reachable from given"
                                   " bookmark"))],
           _('hg strip [-k] [-f] [-n] [-B bookmark] [-r] REV...'))
--- a/mercurial/cmdutil.py	Tue Mar 17 22:21:09 2015 -0400
+++ b/mercurial/cmdutil.py	Tue Mar 17 22:47:08 2015 +0900
@@ -588,7 +588,7 @@
                 srcexists = True
             except IOError, inst:
                 if inst.errno == errno.ENOENT:
-                    ui.warn(_('%s: deleted in working copy\n') % relsrc)
+                    ui.warn(_('%s: deleted in working directory\n') % relsrc)
                     srcexists = False
                 else:
                     ui.warn(_('%s: cannot copy - %s\n') %
--- a/tests/test-copy.t	Tue Mar 17 22:21:09 2015 -0400
+++ b/tests/test-copy.t	Tue Mar 17 22:47:08 2015 +0900
@@ -138,7 +138,7 @@
 moving a missing file
   $ rm foo
   $ hg mv foo foo3
-  foo: deleted in working copy
+  foo: deleted in working directory
   foo3 does not exist!
   $ hg up -qC .
 
--- a/tests/test-globalopts.t	Tue Mar 17 22:21:09 2015 -0400
+++ b/tests/test-globalopts.t	Tue Mar 17 22:47:08 2015 +0900
@@ -309,7 +309,7 @@
    grep          search for a pattern in specified files and revisions
    heads         show branch heads
    help          show help for a given topic or a help overview
-   identify      identify the working copy or specified revision
+   identify      identify the working directory or specified revision
    import        import an ordered set of patches
    incoming      show new changesets found in source
    init          create a new repository in the given directory
@@ -390,7 +390,7 @@
    grep          search for a pattern in specified files and revisions
    heads         show branch heads
    help          show help for a given topic or a help overview
-   identify      identify the working copy or specified revision
+   identify      identify the working directory or specified revision
    import        import an ordered set of patches
    incoming      show new changesets found in source
    init          create a new repository in the given directory
--- a/tests/test-help.t	Tue Mar 17 22:21:09 2015 -0400
+++ b/tests/test-help.t	Tue Mar 17 22:47:08 2015 +0900
@@ -72,7 +72,7 @@
    grep          search for a pattern in specified files and revisions
    heads         show branch heads
    help          show help for a given topic or a help overview
-   identify      identify the working copy or specified revision
+   identify      identify the working directory or specified revision
    import        import an ordered set of patches
    incoming      show new changesets found in source
    init          create a new repository in the given directory
@@ -147,7 +147,7 @@
    grep          search for a pattern in specified files and revisions
    heads         show branch heads
    help          show help for a given topic or a help overview
-   identify      identify the working copy or specified revision
+   identify      identify the working directory or specified revision
    import        import an ordered set of patches
    incoming      show new changesets found in source
    init          create a new repository in the given directory
@@ -690,7 +690,7 @@
    grep          search for a pattern in specified files and revisions
    heads         show branch heads
    help          show help for a given topic or a help overview
-   identify      identify the working copy or specified revision
+   identify      identify the working directory or specified revision
    import        import an ordered set of patches
    incoming      show new changesets found in source
    init          create a new repository in the given directory
@@ -1656,7 +1656,7 @@
   identify
   </a>
   </td><td>
-  identify the working copy or specified revision
+  identify the working directory or specified revision
   </td></tr>
   <tr><td>
   <a href="/help/import">
--- a/tests/test-strip.t	Tue Mar 17 22:21:09 2015 -0400
+++ b/tests/test-strip.t	Tue Mar 17 22:47:08 2015 +0900
@@ -636,7 +636,7 @@
    -f --force          force removal of changesets, discard uncommitted changes
                        (no backup)
       --no-backup      no backups
-   -k --keep           do not modify working copy during strip
+   -k --keep           do not modify working directory during strip
    -B --bookmark VALUE remove revs only reachable from given bookmark
       --mq             operate on patch repository
--- a/mercurial/commands.py	Tue Mar 17 22:21:09 2015 -0400
+++ b/mercurial/commands.py	Tue Mar 17 22:47:08 2015 +0900
@@ -1263,8 +1263,8 @@
     return cmdutil.cat(ui, repo, ctx, m, '', **opts)
 
 @command('^clone',
-    [('U', 'noupdate', None,
-     _('the clone will include an empty working copy (only a repository)')),
+    [('U', 'noupdate', None, _('the clone will include an empty working '
+                               'directory (only a repository)')),
     ('u', 'updaterev', '', _('revision, tag or branch to check out'), _('REV')),
     ('r', 'rev', [], _('include the specified changeset'), _('REV')),
     ('b', 'branch', [], _('clone only the specified branch'), _('BRANCH')),
@@ -2906,8 +2906,9 @@
     """manually set the parents of the current working directory
 
     This is useful for writing repository conversion tools, but should
-    be used with care. For example, neither the working copy nor the dirstate
-    is updated, so file status may be incorrect after running this command.
+    be used with care. For example, neither the working directory nor the
+    dirstate is updated, so file status may be incorrect after running this
+    command.
 
     Returns 0 on success.
     """
@@ -3234,7 +3235,7 @@
     removed files).
 
     If no patterns are given to match, this command prints the names
     of all files under Mercurial control in the working copy.
 
     .. container:: verbose
 
@@ -3920,7 +3921,7 @@
     optionalrepo=True)
 def identify(ui, repo, source=None, rev=None,
              num=None, id=None, branch=None, tags=None, bookmarks=None, **opts):
     """identify the working copy or specified revision
 
     Print a summary identifying the repository state at REV using one or
     two parent hash identifiers, followed by a "+" if the working
@@ -3234,7 +3235,7 @@
 
     If no patterns are given to match, this command prints the names
-    of all files under Mercurial control in the working copy.
+    of all files under Mercurial control in the working directory.
 
     .. container:: verbose
@@ -3920,7 +3921,7 @@
 def identify(ui, repo, source=None, rev=None,
              num=None, id=None, branch=None, tags=None, bookmarks=None, **opts):
-    """identify the working copy or specified revision
+    """identify the working directory or specified revision
 
     Print a summary identifying the repository state at REV using one or